function fix_con

% FIX_CON Show the help for the functions in this toolbox.

% This file is automatically generated.  Matthew Simoneau, 09-04-98
% Copyright (c) 1984-98 by The MathWorks, Inc. All Rights Reserved
% $Revision: 1.8 $ $Date: 1998/10/16 23:19:19 $

helpwin('fix_con/Contents');

function Contents
%MATLAB Tour Partial Function Help:  fix_con
%
%Double click on any function for more information
%
%  Fixed-Point Blockset
%  Version 2.0 (R11) 10-Jul-1998
% 
%  Library and Examples.
%    fixptlib  - Fixed-point block library
%    fixptsys  - Examples of filters and systems
%    fixptdemo - Demos
% 
%  Define Data Types
%    sfix  -   signed fixed point
%    ufix  - unsigned fixed point
%    sint  -   signed integers
%    uint  - unsigned integers
%    sfrac -   signed fractional
%    ufrac - unsigned fractional
%    float - floating point doubles, singles, or custom
%  
%  Design Tools
%    autofixexp         - automatically set radix points based on last simulation
%    showfixptsimranges - show mins and maxs from last simulation
%    fxptdlg            - GUI for autoscaling, min/max browsing, etc.
%

function fixptlib
%MATLAB Tour Partial Function Help:  fix_con
%
%fixptlib is a Simulink model

function fixptsys
%MATLAB Tour Partial Function Help:  fix_con
%
%fixptsys is a Simulink model

function fixptdemo
%MATLAB Tour Partial Function Help:  fix_con
%
%fixptdemo is a Simulink model

function sfix
%MATLAB Tour Partial Function Help:  fix_con
%
% SFIX Create structure describing Signed FIXed point data type
% 
%     This data type structure can be passed to the 
%     Fixed Point Blockset.
% 
%     SFIX( TotalBits )
% 
%     For example, SFIX(16) returns a MATLAB structure
%     that describes the data type of a 
%     16 bit Signed FIXed point number.
% 
%     Note: A default radix point is not included in the data type
%     description.  The radix point would be given as separate
%     block parameter that describes the scaling.
% 
%     

function ufix
%MATLAB Tour Partial Function Help:  fix_con
%
% UFIX Create structure describing Unsigned FIXed point data type
% 
%     This data type structure can be passed to the 
%     Fixed Point Blockset.
% 
%     UFIX( TotalBits )
% 
%     For example, UFIX(16) returns a MATLAB structure
%     that describes the data type of a 
%     16 bit Unsigned FIXed point number.
% 
%     Note: A default radix point is not included in the data type
%     description.  The radix point would be given as separate
%     block parameter that describes the scaling.
% 
%     

function sint
%MATLAB Tour Partial Function Help:  fix_con
%
% SINT Create structure describing Signed INTeger data type
% 
%     This data type structure can be passed to the 
%     Fixed Point Blockset.
% 
%     SINT( TotalBits )
% 
%     For example, SINT(16) returns a MATLAB structure
%     that describes the data type of a 
%     16 bit Signed INTeger number.
% 
%     Note: for integer types, the radix point is just
%     to the right of all bits.
% 
%     

function uint
%MATLAB Tour Partial Function Help:  fix_con
%
% UINT Create structure describing Unsigned INTeger data type
% 
%     This data type structure can be passed to the 
%     Fixed Point Blockset.
% 
%     UINT( TotalBits )
% 
%     For example, UINT(16) returns a MATLAB structure
%     that describes the data type of a 
%     16 bit Unsigned INTeger number.
% 
%     Note: for integer types, the radix point is just
%     to the right of all bits.
% 
%     

function sfrac
%MATLAB Tour Partial Function Help:  fix_con
%
% SFRAC Create structure describing Signed FRACtional data type
% 
%     This data type structure can be passed to the 
%     Fixed Point Blockset.
% 
%     SFRAC( TotalBits )
% 
%       For example, SFRAC(5) returns a MATLAB structure
%       that describes the data type of a 
%       5 bit Signed FRACtional number.
%       Note: the DEFAULT radix point is assumed to lie immediately
%       to the right of the sign bit.  In this example,
%       the range is -1 to 1-2^(1-5) = 0.9375
% 
%     SFRAC( TotalBits, GuardBits )
% 
%       For example, SFRAC(8,4) returns a MATLAB structure
%       that describes the data type of a 
%       8 bit Signed FRACtional number with 4 guard bits.
%       Note: in addition to the sign, 4 guard bits lie to the left
%       of the DEFAULT radix point.  In this example,
%       the range is -1*2^(4) = 16 to (1-2^(1-8))*2^(4) = 15.875
% 
%     

function ufrac
%MATLAB Tour Partial Function Help:  fix_con
%
% UFRAC Create structure describing Unsigned FRACtional data type
% 
%     This data type structure can be passed to the 
%     Fixed Point Blockset.
% 
%     UFRAC( TotalBits )
% 
%       For example, SFRAC(5) returns a MATLAB structure
%       that describes the data type of a 
%       5 bit Unsigned FRACtional number.
%       Note: the DEFAULT radix point is assumed to lie to the
%       left of all the bits.  In this example,
%       the range is 0 to 1-2^(-5) = 0.96875
% 
%     UFRAC( TotalBits, GuardBits )
% 
%       For example, SFRAC(8,4) returns a MATLAB structure
%       that describes the data type of a 
%       8 bit Unsigned FRACtional number with 4 guard bits.
%       Note: 4 guard bits lie to the left
%       of the DEFAULT radix point.  In this example,
%       the range is 0 to (1-2^(-8))*2^(4) = 15.9375
% 
%     

function float
%MATLAB Tour Partial Function Help:  fix_con
%
% FLOAT Create structure describing a floating point data type
% 
%     This data type structure can be passed to the 
%     Fixed Point Blockset.
% 
%     FLOAT( 'single' )
% 
%       Returns a MATLAB structure that describes the data type of
%       an IEEE Single (32 total bits, 8 exponent bits).
% 
%     FLOAT( 'double' )
% 
%       Returns a MATLAB structure that describes the data type of
%       an IEEE Double (64 total bits, 11 exponent bits).
% 
%     FLOAT( TotalBits, ExpBits )
% 
%       Returns a MATLAB structure that describes a floating point 
%       data type.  The data type is assumed to mimic the IEEE style.
%       For example, numbers are normalized with a hidden leading one
%       for all exponents except the smallest possible exponent.  However,
%       the largest possible exponent might not be treated as a flag for
%       INFs and NANs.
% 
%    Note: Unlike fixed point numbers, floating point numbers are ignore any
%       specified scaling: radix point, slope, or bias.  The floating point
%       number and the real world number are the same.
% 
%     

function autofixexp
%MATLAB Tour Partial Function Help:  fix_con
%
% 
%  This script automatically changes the scaling on
%  all Fixed Point blocks that do not have their scaling locked.
%  This file uses min-max data obtain from the last
%  simulation run.
% 

function showfixptsimranges
%MATLAB Tour Partial Function Help:  fix_con
%
% 
%  Show the max and min values from the last Fixed Point Simulation
% 

function fxptdlg
%MATLAB Tour Partial Function Help:  fix_con
%
% FXPTDLG Graphical interface for Fixed-Point Blockset simulation log.
% 
%    FXPTDLG('MODEL') opens the Fixed-Point Blockset graphical user 
%    interface (GUI) which provides access to the simulation log displayed
%    by SHOWFIXPTSIMRANGES.  This GUI is an alternative to using that script.
% 
%    'MODEL' is the name of the Fixed-Point MDL block model the GUI will 
%    use.  Multiple GUIs can be opened for different MDL models.  The MODEL's
%    Name, Data Type and Max/Min Values are displayed.  If the data type is
%    Fixed-Point, then the MantBits is also displayed providing the sign bit
%    value.
% 
%    GUI Options:
%       LOG MIN/MAX       - The GUI allows you to log 'All' or 'None' of 
%                           the minimums and maximums displayed by
%                           SHOWFIXPTSIMRANGES.
%       LOG TYPE          - Allows to 'Overwrite' FixPtSimRanges or 'Merge' 
%                           subsequent simulations with the current
%                           FixPtSimRanges.
%       DOUBLES OVERRIDE  - Block data types can be set to doubles for 'All' 
%                           or 'None' of the blocks.  Setting to 'Use block params'
%                           uses the current block settings in the model's Block
%                           Parameters Dialog Box.
%       AUTOSCALE         - The percent safety margin for autoscaling exponents 
%                           can be set.  Values can range from:
%                                       % Safety Margin > -100%
%                           This value appropriately sets the RangeFactor value.
%                           To update the GUI display after autoscaling, the
%                           model will need to be simulated.
%       RUN               - Running the simulation from the GUI will run the
%                           model and update the display to the latest values
%                           of FixPtSimRanges.
%       STOP              - Stops running the simulation.
%       PLOT              - Opens the plot interface containing any ToWorkspace,
%                           Outport or Scope blocks found in the model.  The raw signal
%                           data or the doubles from these blocks can be plotted.
%                         - To update the double values used for plotting, run the
%                           simulation through the GUI with the Doubles Override set 
%                           to 'All'.
%                         - The data generated by the last, complete GUI simulation run
%                           is considered the latest raw signal data and is therefore used
%                           for plotting.
% 
%    

